<!DOCTYPE html>
<html>
<head>
<meta charset="UTF-8">
<title>.</title>
<style type="text/css">
body {
    --font-size-medium: {{ mediumFontSize }}pt;
    --font-serif: {{ serifFont }};
    --font-standard: {{ standardFamilyFont }};
}
{{ css }}
{{ sidebarCss }}
</style>
</head>
<body>
{% if articles %}
{% for article in articles %}
  <hr>
  <div class="actiontable">
    <div class="actionrowtable">
      {% with article.articleStatus as result %}
          {% ifequal article.Unread result %}
          <div class="theactioncell"><a href="akregatoraction:markAsRead{{ article.actionToken }}">{% icon "mail-mark-read" small _("Mark as Read") %}</a></div>
          {% endifequal %}
          {% ifequal article.Read result %}
          <div class="theactioncell"><a href="akregatoraction:markAsUnRead{{ article.actionToken }}">{% icon "mail-mark-unread" small _("Mark as Unread") %}</a></div>
          {% endifequal %}
      {% endwith %}
      {% if article.important %}
        <div class="theactioncell"><a href="akregatoraction:markAsImportant{{ article.actionToken }}">{% icon "mail-message" small _("Remove Important Status") %}</a></div>
      {% else %}
        <div class="theactioncell"><a href="akregatoraction:markAsImportant{{ article.actionToken }}">{% icon "mail-mark-important" small _("Mark as Important") %}</a></div>
      {% endif %}
      <div class="theactioncell"><a href="akregatoraction:openInExternalBrowser{{ article.actionToken }}">{% icon "window-new" small _("Open Link in External Browser") %}</a></div>
      <div class="theactioncell"><a href="akregatoraction:openInBackgroundTab{{ article.actionToken }}">{% icon "tab-new" small _("Open In Background Tab") %}</a></div>
      <div class="theactioncell"><a href="akregatoraction:sendFileArticle{{ article.actionToken }}">{% icon "mail-message-new" small _("Send File Address") %}</a></div>
      <div class="theactioncell"><a href="akregatoraction:sendUrlArticle{{ article.actionToken }}">{% icon "mail-message-new" small _("Send Link Address") %}</a></div>
      <div class="theactioncell theactionbigcell"><a href="akregatoraction:delete{{ article.actionToken }}">{% icon "edit-delete" small _("Delete Article") %}</a></div>
    </div>
  </div>


  <div class="headerbox">
  {% if article.imageFeed %}
  {{ article.imageFeed|safe }}
  {% endif %}

  {% if article.strippedTitle %}
  <div class="headertitle" dir="{{ applicationDir }}"><a href="{{ article.articleLinkUrl }}">{{ article.strippedTitle|safe }}</a></div>
  {% endif %}

  {%if article.articlePubDate %}
  <div><span class="header" dir="{{ applicationDir }}">{{ dateI18n }}:</span>
      {{ article.articlePubDate }}</div>
  {% endif %}

  {% if article.author %}
  <div><span class="header" dir="{{ applicationDir }}">{{ authorI18n }}:</span>
     {{ article.author|safe }}</div>
  {% endif %}

  {% if article.enclosure %}
  <div><span class="header" dir="{{ applicationDir }}">{{ enclosureI18n }}:</span>
      {{ article.enclosure|safe }}</div>
  {% endif %}
  </div>

  {% if article.content %}
  <hr>
  <div dir="{{ applicationDir }}"><span class="content">{{ article.content|safe }}</span></div>
  {% endif %}

  {% if article.articleCompleteStoryLink %}
  <p><a class="contentlink" href="{{ article.articleCompleteStoryLink }}">{{ completeStoryI18n }}</a></p>
  {% endif %}

{% endfor %}
{% endif %}

</body>
</html>
