<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<style type="text/css">
body {
    --font-size-medium: {{ mediumFontSize }}pt;
    --font-serif: {{ serifFont }};
    --font-standard: {{ standardFamilyFont }};
}
{{ css }}
{{ sidebarCss }}
</style>
<title>.</title>
</head>
<body>
<div class="headertitle" dir="{{ applicationDir }}">{{ strippedTitle }}{{ feedCount }}</div>
{{ feedImage|safe }}
{{ feedDescription|safe }}
{{ feedHomePage|safe }}
{{ feedCopyright|safe }}
</body>
</html>
