<!DOCTYPE html>
<html>
<head>
<meta charset="UTF-8">
<style type="text/css">
body {
    --font-size-medium: {{ mediumFontSize }}pt;
    --font-serif: {{ serifFont }};
    --font-standard: {{ standardFamilyFont }};
}
{{ css }}
{{ sidebarCss }}
</style>
<title>.</title>
</head>
<body>
{% if not loadExternalReference %}
    <p class="advisory">
        {% i18n_var "<b>Note:</b> For security reasons, external reference is blocked (See configure dialog)." as msg %}
        {{ msg|safe }}
    </p>
{% endif %}

{% if articles %}
{% for article in articles %}
  <header>
    {% if article.imageFeed %}
    <div class="header-image">
        {{ article.imageFeed|safe }}
    </div>
    {% endif %}

    {% if article.strippedTitle %}
    <a class="header-title" href="{{ article.articleLinkUrl }}" dir="{{ applicationDir }}">
        <h1>{{ article.strippedTitle|safe }}</h1>
    </a>
    {% endif %}

    {% if article.author %}
    <div class="header-author">
        {{ article.author|safe }}
        {%if article.articlePubDate %}
            <time class="header-date">
                {{ article.articlePubDate }}
            </time>
        {% endif %}
    </div>
    {% endif %}

    {% if article.enclosure %}
    <div class="article-enclosure">
        <span dir="{{ applicationDir }}">{{ enclosureI18n }}: </span>
        <span class="enclosure">{{ article.enclosure|safe }}</span>
    </div>
    {% endif %}
  </header>

  {% if article.content %}
  <div dir="{{ applicationDir }}">
    <article class="content">{{ article.content|safe }}</article>
  </div>
  {% endif %}

  {% if article.articleCompleteStoryLink %}
  <div class="complete-link">
    <hr>
    <a href="{{ article.articleCompleteStoryLink }}">{{ completeStoryI18n }}</a>
  </div>
  {% endif %}
{% endfor %}
{% endif %}

</body>
</html>
