<!DOCTYPE HTML>
<html>
<head>
<meta charset="UTF-8">
<style type="text/css">
body {
    --font-size-medium: {{ mediumFontSize }}pt;
    --font-serif: {{ serifFont }};
    --font-standard: {{ standardFamilyFont }};
}
{{ css }}
{{ sidebarCss }}
</style>
<title>.</title>
</head>
<body>
<div class="headertitle" dir="{{ applicationDir }}">{{ nodeTitle }} {{nodeCount}}</div>
</body>
</html>
