{% extends "main.html" %}

{% block style %}
.links {
    margin: auto;
}

.links td {
    padding-top: 5px;
    padding-bottom: 5px;
}

{% endblock style %}

{% block box %}

<div>
    <p>{% i18n "Feed readers provide a convenient way to browse different kinds of content, including news, blogs, and other content from online sites. Instead of checking all your favorite web sites manually for updates, Akregator collects the content for you." %}</p>
    <p>{% i18n_var "For more information about using Akregator, check the <a href='https://kontact.kde.org/components/akregator/'>Akregator website</a>. If you do not want to see this page anymore, <a href='config:/disable_introduction'>click here</a>." as features %} {{ features|safe }}</p>
</div>

{% endblock box %}
