// doxy.h --
// This is part of Metakit, see http://www.equi4.com/metakit.html

/** @mainpage Metakit API Reference

The is the reference documentation for the public C++ API of Metakit.

- For the documentation of Metakit, see http://www.equi4.com/mkdocs.html
- To use Metakit from Python, see http://www.equi4.com/metakit/python.html
- To use Metakit from Tcl, see http://www.equi4.com/metakit/tcl.html

@section install Installation

- Windows: open "win/msvc60/mksrc.dsw" with Microsoft Visual C++ 6.0
- Unix: "cd builds; ../unix/configure; make; make test; make install"

@section using Using the library

- There are some examples in the "demo/" and "examples/" directories.
- The "tests/" directory contains a test suite with 140+ small samples.

@section news News, releases, discussions

- See the Metakit homepage at http://www.equi4.com/metakit.html
 */
